@@ -558,7 +558,9 @@ sub rows {
 
   # Prep the rows
   foreach (@$rows) {
+    next if (!defined($_));
     foreach (@$_) {
+      next if (!defined($_));
       # Zap leading and trailing white space
       s/^\s+//;
       s/\s+$//;
@@ -716,6 +718,11 @@ sub non_quote_row {
   my @non_quotes;
   foreach (0 .. $#$row) {
     next if $_ == $dcol;
+    # Rows which have undefined fields
+    # (Yahoo include "date,dividend" in with the quotes)
+    if (!defined($row->[$_])) {
+      return $row;
+    }
     next if $row->[$_] =~ /^\s*$/;
     if ($row->[$_] !~ /^\s*\$*[\d\.,]+\s*$/) {
       return $row;
@@ -1202,7 +1209,7 @@ care of setting this appropriately. The default is 0.
 
 (The default value is 0.)
 
-If true, Twe fetch each batch of rows in the reverse order to that
+If true, we fetch each batch of rows in the reverse order to that
 provided by C<quote_urls()>.
 
 Note that the order of rows within blocks is not affected,
